@@ -185,9 +185,8 @@ uniquegenelist(letters[1:8],ndups=2,spacing=2)
 
 tstat <- matrix(c(0,5,0, 0,2.5,0, -2,-2,2, 1,1,1), 4, 3, byrow=TRUE)
 classifyTestsF(tstat)
-FStat(tstat)
-classifyTestsT(tstat)
-classifyTestsP(tstat)
+classifyTestsF(tstat,fstat.only=TRUE)
+limma:::.classifyTestsP(tstat)
 
 ### avereps
 
@@ -252,6 +251,16 @@ fit$df.prior
 fit$s2.prior
 summary(fit$s2.post)
 
+### eBayes with robust
+
+fitr <- lmFit(y,design)
+fitr <- eBayes(fitr,robust=TRUE)
+summary(fitr$df.prior)
+topTable(fitr,coef=2)
+fitr <- eBayes(fitr,trend=TRUE,robust=TRUE)
+summary(fitr$df.prior)
+topTable(fitr,coef=2)
+
 ### voom
 
 y <- matrix(rpois(100*4,lambda=20),100,4)
